@@ -5,14 +5,19 @@
 
 更多信息请看[文档](https://yiri-mirai.vercel.app/)。
 """
-__version__ = '0.2.3.1'
+__version__ = '0.2.4'
 __author__ = '忘忧北萱草'
 
 import logging
+from typing import TYPE_CHECKING
+
+if TYPE_CHECKING:
+    from mirai.adapters import (
+        Adapter, ComposeAdapter, HTTPAdapter, WebHookAdapter, WebSocketAdapter
+    )
+else:
+    from mirai.adapters import Adapter
 
-from mirai.adapters import (
-    Adapter, ComposeAdapter, HTTPAdapter, WebHookAdapter, WebSocketAdapter
-)
 from mirai.api_provider import Method
 from mirai.bot import (
     LifeSpan, Mirai, MiraiRunner, Shutdown, SimpleMirai, Startup
@@ -56,5 +61,17 @@ def get_logger() -> logging.Logger:
     """获取 YiriMirai 的模块 Logger。
 
     所有的模块的 Logger 都是此 Logger 的子 Logger，修改此 Logger 的属性以应用到 YiriMirai 全局。
+
+    Returns:
+        logging.Logger: 模块 Logger。
     """
     return logger
+
+
+def __getattr__(name):
+    if name in (
+        'HTTPAdapter', 'WebSocketAdapter', 'WebHookAdapter', 'ComposeAdapter'
+    ):
+        import mirai.adapters
+        return getattr(mirai.adapters, name)
+    raise AttributeError(f'Module {__name__} has no attribute {name}')
