@@ -11,8 +11,6 @@ from typing import (
     Union, cast
 )
 
-import aiofiles
-
 if TYPE_CHECKING:
     from typing import Literal
 else:
@@ -34,7 +32,9 @@ from mirai.models.events import (
     FriendMessage, GroupMessage, OtherClientMessage, RequestEvent,
     StrangerMessage, TempMessage
 )
-from mirai.models.message import Image, MessageChain, MessageComponent, Voice
+from mirai.models.message import (
+    Image, MessageChain, MessageComponent, TMessage, Voice
+)
 from mirai.utils import async_
 
 logger = logging.getLogger(__name__)
@@ -69,7 +69,7 @@ class SessionInfoResponse(Response):
 
     class Data(MiraiBaseModel):
         session_key: str = 'SINGLE_SESSION'
-        """session_key，不知道干啥用的。"""
+        """session_key。"""
         qq: Friend
         """机器人信息。"""
 
@@ -273,8 +273,7 @@ class ApiModel(ApiBaseModel):
                 raise TypeError(
                     f'在 `{self.Info.alias}` 中，具名参数 `{name}` 与位置参数重复。'
                 )
-            else:
-                kwargs[name] = value
+            kwargs[name] = value
 
         super().__init__(**kwargs)
 
@@ -285,10 +284,32 @@ class ApiModel(ApiBaseModel):
         except ValueError as e:
             raise ValueError(f'`{name}` 不是可用的 API！') from e
 
+    async def call(
+        self,
+        api_provider: ApiProvider,
+        method: Method = Method.GET,
+        response_type: Optional[Type[TModel]] = None,
+    ) -> Optional[TModel]:
+        """调用 API。"""
+        info = self.Info
+        logger.debug(f'调用 API：{repr(self)}')
+        raw_response = await api_provider.call_api(
+            api=info.name,
+            method=method,
+            **self.dict(by_alias=True, exclude_none=True)
+        )
+
+        # 如果 API 无法调用，raw_response 为空
+        if not raw_response:
+            return None
+        # 解析 API 返回数据
+        response_type = cast(Type[TModel], response_type or info.response_type)
+        return response_type.parse_obj(raw_response)
+
     class Proxy(Generic[TModel]):
         """API 代理类。由 API 构造，提供对适配器的访问。
 
-        `Proxy` 提供更加简便的调用 API 的写法。`Proxy` 对象一般由 `Mirai.__getattr__` 获得，
+            Proxy: 提供更加简便的调用 API 的写法。`Proxy` 对象一般由 `Mirai.__getattr__` 获得，
         这个方法依托于 `MiraiIndexedModel` 的子类获取机制，支持按照命名规范转写的 API，
         所有的 API 全部使用小写字母及下划线命名。
 
@@ -330,7 +351,7 @@ class ApiModel(ApiBaseModel):
             self,
             method: Method = Method.GET,
             response_type: Optional[Type[TModel]] = None,
-            args: Optional[Union[list, tuple]] = None,
+            args: Union[list, tuple, None] = None,
             kwargs: Optional[dict] = None
         ) -> Optional[TModel]:
             """调用 API。
@@ -341,25 +362,7 @@ class ApiModel(ApiBaseModel):
             kwargs = kwargs or {}
 
             api = self.api_type(*args, **kwargs)
-            info = self.api_type.Info
-            logger.debug(f'调用 API：{repr(api)}')
-            if isinstance(api, CustomApiModel):
-                raw_response = await api.call(self.api_provider)
-            else:
-                raw_response = await self.api_provider.call_api(
-                    api=info.name,
-                    method=method,
-                    **api.dict(by_alias=True, exclude_none=True)
-                )
-
-            # 如果 API 无法调用，raw_response 为空
-            if not raw_response:
-                return None
-            # 解析 API 返回数据
-            response_type = cast(
-                Type[TModel], response_type or info.response_type
-            )
-            return response_type.parse_obj(raw_response)
+            return await api.call(self.api_provider, method, response_type)
 
         async def get(self, *args, **kwargs) -> Optional[TModel]:
             """获取。对于 GET 方法的 API，调用此方法。"""
@@ -377,13 +380,6 @@ class ApiModel(ApiBaseModel):
             return await self.get(*args, **kwargs)
 
 
-class CustomApiModel(ApiBaseModel):
-    """自定义调用方式的 API。"""
-    @abc.abstractmethod
-    async def call(self, api_provider: ApiProvider):
-        """调用 API。"""
-
-
 class ApiGet(ApiModel):
     class Proxy(ApiModel.Proxy[TModel]):
         async def set(self, *args, **kwargs):
@@ -554,22 +550,20 @@ class MemberProfile(ApiGet):
 
 class SendMessage(ApiBaseModel):
     """发送消息的 API 的方法复用，不作为 API 使用。"""
-    # message_chain: Union[MessageChain, Iterable[Union[MessageComponent, str]], str]
+    # message_chain: TMessage
 
     @validator('message_chain', check_fields=False)
     def _validate_message_chain(cls, value: Union[MessageChain, list]):
         if isinstance(value, list):
             return MessageChain.parse_obj(value)
-        elif isinstance(value, MessageChain):
-            return value
+        return value
 
 
 class SendFriendMessage(ApiPost, SendMessage):
     """发送好友消息。"""
     target: int
     """发送消息目标好友的 QQ 号。"""
-    message_chain: Union[MessageChain, Iterable[Union[MessageComponent, str]],
-                         str]
+    message_chain: TMessage
     """消息链。"""
     quote: Optional[int] = None
     """可选。引用一条消息的 message_id 进行回复。"""
@@ -583,8 +577,7 @@ class SendGroupMessage(ApiPost, SendMessage):
     """发送群消息。"""
     target: int
     """发送消息目标群的群号。"""
-    message_chain: Union[MessageChain, Iterable[Union[MessageComponent, str]],
-                         str]
+    message_chain: TMessage
     """消息链。"""
     quote: Optional[int] = None
     """可选。引用一条消息的 message_id 进行回复。"""
@@ -600,8 +593,7 @@ class SendTempMessage(ApiPost, SendMessage):
     """临时会话对象 QQ 号。"""
     group: int
     """临时会话对象群号。"""
-    message_chain: Union[MessageChain, Iterable[Union[MessageComponent, str]],
-                         str]
+    message_chain: TMessage
     """消息链。"""
     quote: Optional[int] = None
     """可选。引用一条消息的 message_id 进行回复。"""
@@ -717,7 +709,7 @@ class FileRename(ApiPost):
         response_type = Response
 
 
-class FileUpload(ApiPost, CustomApiModel):
+class FileUpload(ApiPost):
     """文件上传。（暂时不可用）"""
     type: Literal["group"]
     """上传的文件类型。"""
@@ -727,7 +719,13 @@ class FileUpload(ApiPost, CustomApiModel):
     """上传的文件的本地路径。"""
     path: str = ''
     """上传目录的 id，空串为上传到根目录。"""
-    async def call(self, api_provider: ApiProvider):
+    async def call(
+        self,
+        api_provider: ApiProvider,
+        method: Method = Method.GET,
+        response_type: Optional[Type[TModel]] = None,
+    ):
+        import aiofiles
         async with aiofiles.open(self.file, 'rb') as f:
             file = await f.read()
         return await api_provider.call_api(
@@ -747,13 +745,19 @@ class FileUpload(ApiPost, CustomApiModel):
         response_type = FileProperties
 
 
-class UploadImage(ApiPost, CustomApiModel):
+class UploadImage(ApiPost):
     """图片文件上传。"""
     type: Literal["friend", "group", "temp"]
     """上传的图片类型。"""
     img: Union[str, Path]
     """上传的图片的本地路径。"""
-    async def call(self, api_provider: ApiProvider):
+    async def call(
+        self,
+        api_provider: ApiProvider,
+        method: Method = Method.GET,
+        response_type: Optional[Type[TModel]] = None,
+    ):
+        import aiofiles
         async with aiofiles.open(self.img, 'rb') as f:
             img = await f.read()
         return await api_provider.call_api(
@@ -769,13 +773,19 @@ class UploadImage(ApiPost, CustomApiModel):
         response_type = Image
 
 
-class UploadVoice(ApiPost, CustomApiModel):
+class UploadVoice(ApiPost):
     """语音文件上传。"""
     type: Literal["group"]
     """上传的语音类型。"""
     voice: Union[str, Path]
     """上传的语音的本地路径。"""
-    async def call(self, api_provider: ApiProvider):
+    async def call(
+        self,
+        api_provider: ApiProvider,
+        method: Method = Method.GET,
+        response_type: Optional[Type[TModel]] = None,
+    ):
+        import aiofiles
         async with aiofiles.open(self.voice, 'rb') as f:
             voice = await f.read()
         return await api_provider.call_api(
@@ -955,7 +965,7 @@ class RespEvent(ApiBaseModel):
         )
 
 
-class RespNewFriendRequestEvent(ApiPost):
+class RespNewFriendRequestEvent(ApiPost, RespEvent):
     """响应添加好友申请。"""
     event_id: int
     """响应申请事件的标识。"""
@@ -972,14 +982,12 @@ class RespNewFriendRequestEvent(ApiPost):
         if isinstance(v, RespOperate):
             if v == RespOperate.ALLOW:
                 return 0
-            elif v == RespOperate.DECLINE:
+            if v == RespOperate.DECLINE:
                 return 1
-            elif v == RespOperate.DECLINE & RespOperate.BAN:
+            if v == RespOperate.DECLINE & RespOperate.BAN:
                 return 2
-            else:
-                raise ValueError(f'无效操作{v}。')
-        else:
-            return v
+            raise ValueError(f'无效操作{v}。')
+        return v
 
     class Info(ApiPost.Info):
         name = "resp/newFriendRequestEvent"
@@ -987,7 +995,7 @@ class RespNewFriendRequestEvent(ApiPost):
         response_type = MiraiBaseModel
 
 
-class RespMemberJoinRequestEvent(ApiPost):
+class RespMemberJoinRequestEvent(ApiPost, RespEvent):
     """响应用户入群申请。"""
     event_id: int
     """响应申请事件的标识。"""
@@ -1004,18 +1012,16 @@ class RespMemberJoinRequestEvent(ApiPost):
         if isinstance(v, RespOperate):
             if v == RespOperate.ALLOW:
                 return 0
-            elif v == RespOperate.DECLINE:
+            if v == RespOperate.DECLINE:
                 return 1
-            elif v == RespOperate.IGNORE:
+            if v == RespOperate.IGNORE:
                 return 2
-            elif v == RespOperate.DECLINE & RespOperate.BAN:
+            if v == RespOperate.DECLINE & RespOperate.BAN:
                 return 3
-            elif v == RespOperate.IGNORE & RespOperate.BAN:
+            if v == RespOperate.IGNORE & RespOperate.BAN:
                 return 4
-            else:
-                raise ValueError(f'无效操作{v}。')
-        else:
-            return v
+            raise ValueError(f'无效操作{v}。')
+        return v
 
     class Info(ApiPost.Info):
         name = "resp/memberJoinRequestEvent"
@@ -1023,7 +1029,7 @@ class RespMemberJoinRequestEvent(ApiPost):
         response_type = MiraiBaseModel
 
 
-class RespBotInvitedJoinGroupRequestEvent(ApiPost):
+class RespBotInvitedJoinGroupRequestEvent(ApiPost, RespEvent):
     """响应被邀请入群申请。"""
     event_id: int
     """响应申请事件的标识。"""
@@ -1040,12 +1046,10 @@ class RespBotInvitedJoinGroupRequestEvent(ApiPost):
         if isinstance(v, RespOperate):
             if v == RespOperate.ALLOW:
                 return 0
-            elif v == RespOperate.DECLINE:
+            if v == RespOperate.DECLINE:
                 return 1
-            else:
-                raise ValueError(f'无效操作{v}。')
-        else:
-            return v
+            raise ValueError(f'无效操作{v}。')
+        return v
 
     class Info(ApiPost.Info):
         name = "resp/botInvitedJoinGroupRequestEvent"
@@ -1061,8 +1065,7 @@ class CmdExecute(ApiPost):
     def _validate_command(cls, value):
         if isinstance(value, list):
             return MessageChain.parse_obj(value)
-        elif isinstance(value, MessageChain):
-            return value
+        return value
 
     class Info(ApiPost.Info):
         name = "cmd/execute"
