@@ -2,26 +2,23 @@
 """
 此模块提供消息链相关。
 """
-import abc
-import base64
-import imghdr
+import itertools
 import logging
 import re
 from datetime import datetime
 from enum import Enum
-from json import loads as json_loads
 from pathlib import Path
-from typing import Iterable, List, Optional, Union, cast
+from typing import (
+    Iterable, List, Optional, Tuple, Type, TypeVar, Union, cast, overload
+)
 
-import aiofiles
-import httpx
 from pydantic import HttpUrl, validator
 
 from mirai.models.base import (
     MiraiBaseModel, MiraiIndexedMetaclass, MiraiIndexedModel
 )
 from mirai.models.entities import Friend, GroupMember
-from mirai.utils import KMP
+from mirai.utils import kmp
 
 logger = logging.getLogger(__name__)
 
@@ -29,7 +26,11 @@ logger = logging.getLogger(__name__)
 def serialize(s: str) -> str:
     """mirai 码转义。
 
-    `s: str` 待转义的字符串。
+    Args:
+        s: 待转义的字符串。
+
+    Returns:
+        str: 去转义后的字符串。
     """
     return re.sub(r'[\[\]:,\\]', lambda match: '\\' + match.group(0),
                   s).replace('\n', '\\n').replace('\r', '\\r')
@@ -38,7 +39,11 @@ def serialize(s: str) -> str:
 def deserialize(s: str) -> str:
     """mirai 码去转义。
 
-    `s: str` 待去转义的字符串。
+    Args:
+        s: 待去转义的字符串。
+
+    Returns:
+        str: 去转义后的字符串。
     """
     return re.sub(
         r'\\([\[\]:,\\])', lambda match: match.group(1),
@@ -96,17 +101,12 @@ class MessageComponent(MiraiIndexedModel, metaclass=MessageComponentMetaclass):
         for name, value in zip(parameter_names, args):
             if name in kwargs:
                 raise TypeError(f'在 `{self.type}` 中，具名参数 `{name}` 与位置参数重复。')
-            else:
-                kwargs[name] = value
+            kwargs[name] = value
 
         super().__init__(**kwargs)
 
 
-class MessagePart():
-    """消息的部分，可转化为消息组件。"""
-    @abc.abstractmethod
-    def as_component(self) -> MessageComponent:
-        """将消息组件化。"""
+TMessageComponent = TypeVar('TMessageComponent', bound=MessageComponent)
 
 
 class MessageChain(MiraiBaseModel):
@@ -186,6 +186,12 @@ class MessageChain(MiraiBaseModel):
         print('Hi!')
     ```
 
+    消息链的 `has` 方法和 `in` 等价。
+    ```py
+    if message_chain.has(AtAll):
+        print('AtAll')
+    ```
+
     也可以使用 `>=` 和 `<= `运算符：
     ```py
     if MessageChain([At(bot.qq), Plain('Hello!')]) <= message_chain:
@@ -201,24 +207,61 @@ class MessageChain(MiraiBaseModel):
     '[Plain("Hello World!")]'
     ```
 
-    以 `类型: 数量` 为索引，获取前至多多少个该类型的消息组件。
+    以 `类型, 数量` 为索引，获取前至多多少个该类型的消息组件。
     ```py
-    plain_list_first = message_chain[Plain: 1]
+    plain_list_first = message_chain[Plain, 1]
     '[Plain("Hello World!")]'
     ```
+
+    消息链的 `get` 方法和索引操作等价。
+    ```py
+    plain_list_first = message_chain.get(Plain)
+    '[Plain("Hello World!")]'
+    ```
+
+    消息链的 `get` 方法还可指定第二个参数 `count`，这相当于以 `类型, 数量` 为索引。
+    ```py
+    plain_list_first = message_chain.get(Plain, 1)
+    # 这等价于
+    plain_list_first = message_chain[Plain, 1]
+    ```
+
+    可以用加号连接两个消息链。
+    ```py
+    MessageChain(['Hello World!']) + MessageChain(['Goodbye World!'])
+    # 返回 MessageChain([Plain("Hello World!"), Plain("Goodbye World!")])
+    ```
+
+    可以用 `*` 运算符复制消息链。
+    ```py
+    MessageChain(['Hello World!']) * 2
+    # 返回 MessageChain([Plain("Hello World!"), Plain("Hello World!")])
+    ```
+
+    除此之外，消息链还支持很多 list 拥有的操作，比如 `index` 和 `count`。
+    ```py
+    message_chain = MessageChain([
+        AtAll(),
+        "Hello World!",
+    ])
+    message_chain.index(Plain)
+    # 返回 0
+    message_chain.count(Plain)
+    # 返回 1
+    ```
+
+    消息链对这些操作进行了拓展。在传入元素的地方，一般都可以传入元素的类型。
     """
     __root__: List[MessageComponent]
 
     @staticmethod
-    def _parse_message_chain(msg_chain: list):
+    def _parse_message_chain(msg_chain: Iterable):
         result = []
         for msg in msg_chain:
             if isinstance(msg, dict):
                 result.append(MessageComponent.parse_obj(msg))
             elif isinstance(msg, MessageComponent):
                 result.append(msg)
-            elif isinstance(msg, MessagePart):
-                result.append(msg.as_component())
             elif isinstance(msg, str):
                 result.append(Plain(msg))
             else:
@@ -229,18 +272,18 @@ class MessageChain(MiraiBaseModel):
 
     @validator('__root__', always=True, pre=True)
     def _parse_component(cls, msg_chain):
-        if isinstance(msg_chain,
-                      str) or isinstance(msg_chain, MessageComponent):
+        if isinstance(msg_chain, (str, MessageComponent)):
             msg_chain = [msg_chain]
         if not msg_chain:
             msg_chain = []
         return cls._parse_message_chain(msg_chain)
 
     @classmethod
-    def parse_obj(cls, msg_chain: list):
+    def parse_obj(cls, msg_chain: Iterable):
         """通过列表形式的消息链，构造对应的 `MessageChain` 对象。
 
-        `msg_chain: list` 列表形式的消息链。
+        Args:
+            msg_chain: 列表形式的消息链。
         """
         result = cls._parse_message_chain(msg_chain)
         return cls(__root__=result)
@@ -257,67 +300,361 @@ class MessageChain(MiraiBaseModel):
     def __iter__(self):
         yield from self.__root__
 
-    def __getitem__(self,
-                    index) -> Union[MessageComponent, List[MessageComponent]]:
+    @overload
+    def get(self, index: int) -> MessageComponent:
+        ...
+
+    @overload
+    def get(self, index: slice) -> List[MessageComponent]:
+        ...
+
+    @overload
+    def get(self, index: Type[TMessageComponent]) -> List[TMessageComponent]:
+        ...
+
+    @overload
+    def get(
+        self, index: Tuple[Type[TMessageComponent], int]
+    ) -> List[TMessageComponent]:
+        ...
+
+    def get(
+        self,
+        index: Union[int, slice, Type[TMessageComponent],
+                     Tuple[Type[TMessageComponent], int]],
+        count: Optional[int] = None
+    ) -> Union[MessageComponent, List[MessageComponent],
+               List[TMessageComponent]]:
+        """获取消息链中的某个（某些）消息组件，或某类型的消息组件。
+
+        Args:
+            index (`Union[int, slice, Type[TMessageComponent], Tuple[Type[TMessageComponent], int]]`):
+                如果为 `int`，则返回该索引处的消息组件。
+                如果为 `slice`，则返回该索引范围处的消息组件。
+                如果为 `Type[TMessageComponent]`，则返回该类型的全部消息组件。
+                如果为 `Tuple[Type[TMessageComponent], int]`，则返回该类型的至多 `index[1]` 个消息组件。
+
+            count: 如果为 `int`，则返回至多 `count` 个消息组件。
+
+        Returns:
+            MessageComponent: 返回指定索引处的消息组件。
+            List[MessageComponent]: 返回指定索引范围的消息组件。
+            List[TMessageComponent]: 返回指定类型的消息组件构成的列表。
+        """
         # 正常索引
         if isinstance(index, int):
             return self.__root__[index]
+        # 切片索引
+        if isinstance(index, slice):
+            return self.__root__[index]
+        # 指定 count
+        if count:
+            if isinstance(index, type):
+                index = (index, count)
+            elif isinstance(index, tuple):
+                index = (index[0], count if count < index[1] else index[1])
         # 索引对象为 MessageComponent 类，返回所有对应 component
-        elif isinstance(index, type):
+        if isinstance(index, type):
             return [
-                cast(MessageComponent, component) for component in self
-                if type(component) == index
+                component for component in self if type(component) is index
             ]
-        # 索引对象为 MessageComponent 和 int 构成的 slice， 返回指定数量的 component
-        elif isinstance(index, slice):
+        # 索引对象为 MessageComponent 和 int 构成的 tuple， 返回指定数量的 component
+        if isinstance(index, tuple):
             components = (
-                component for component in self
-                if type(component) == index.start
+                component for component in self if type(component) is index[0]
             )
             return [
-                component
-                for component, _ in zip(components, range(index.stop))
+                component for component, _ in zip(components, range(index[1]))
             ]
         raise TypeError(f"消息链索引需为 int 或 MessageComponent，当前类型：{type(index)}")
 
-    def __contains__(self, sub) -> bool:
+    def get_first(self,
+                  t: Type[TMessageComponent]) -> Optional[TMessageComponent]:
+        """获取消息链中第一个符合类型的消息组件。"""
+        for component in self:
+            if isinstance(component, t):
+                return component
+        return None
+
+    @overload
+    def __getitem__(self, index: int) -> MessageComponent:
+        ...
+
+    @overload
+    def __getitem__(self, index: slice) -> List[MessageComponent]:
+        ...
+
+    @overload
+    def __getitem__(self,
+                    index: Type[TMessageComponent]) -> List[TMessageComponent]:
+        ...
+
+    @overload
+    def __getitem__(
+        self, index: Tuple[Type[TMessageComponent], int]
+    ) -> List[TMessageComponent]:
+        ...
+
+    def __getitem__(
+        self, index: Union[int, slice, Type[TMessageComponent],
+                           Tuple[Type[TMessageComponent], int]]
+    ) -> Union[MessageComponent, List[MessageComponent],
+               List[TMessageComponent]]:
+        return self.get(index)
+
+    def __setitem__(
+        self, key: Union[int, slice],
+        value: Union[MessageComponent, str, Iterable[Union[MessageComponent,
+                                                           str]]]
+    ):
+        if isinstance(value, str):
+            value = Plain(value)
+        if isinstance(value, Iterable):
+            value = (Plain(c) if isinstance(c, str) else c for c in value)
+        self.__root__[key] = value  # type: ignore
+
+    def __delitem__(self, key: Union[int, slice]):
+        del self.__root__[key]
+
+    def __reversed__(self) -> Iterable[MessageComponent]:
+        return reversed(self.__root__)
+
+    def has(
+        self, sub: Union[MessageComponent, Type[MessageComponent],
+                         'MessageChain', str]
+    ) -> bool:
+        """判断消息链中：
+        1. 是否有某个消息组件。
+        2. 是否有某个类型的消息组件。
+        3. 是否有某个子消息链。
+        4. 对应的 mirai 码中是否有某子字符串。
+
+        Args:
+            sub (`Union[MessageComponent, Type[MessageComponent], 'MessageChain', str]`):
+                若为 `MessageComponent`，则判断该组件是否在消息链中。
+                若为 `Type[MessageComponent]`，则判断该组件类型是否在消息链中。
+                若为 `MessageChain`，则判断该子消息链是否在消息链中。
+                若为 `str`，则判断对应的 mirai 码中是否有某子字符串。
+
+        Returns:
+            bool: 是否找到。
+        """
         if isinstance(sub, type):  # 检测消息链中是否有某种类型的对象
             for i in self:
-                if type(i) == sub:
+                if type(i) is sub:
                     return True
-            else:
-                return False
-        elif isinstance(sub, MessageComponent):  # 检查消息链中是否有某个组件
+            return False
+        if isinstance(sub, MessageComponent):  # 检查消息链中是否有某个组件
             for i in self:
                 if i == sub:
                     return True
-            else:
-                return False
-        elif isinstance(sub, MessageChain):  # 检查消息链中是否有某个子消息链
-            return bool(KMP(self, sub))
-        elif isinstance(sub, str):  # 检查消息中有无指定字符串子串
+            return False
+        if isinstance(sub, MessageChain):  # 检查消息链中是否有某个子消息链
+            return bool(kmp(self, sub))
+        if isinstance(sub, str):  # 检查消息中有无指定字符串子串
             return sub in deserialize(str(self))
         raise TypeError(f"类型不匹配，当前类型：{type(sub)}")
 
+    def __contains__(self, sub) -> bool:
+        return self.has(sub)
+
     def __ge__(self, other):
         return other in self
 
     def __len__(self) -> int:
         return len(self.__root__)
 
+    def __add__(
+        self, other: Union['MessageChain', MessageComponent, str]
+    ) -> 'MessageChain':
+        if isinstance(other, MessageChain):
+            return self.__class__(self.__root__ + other.__root__)
+        if isinstance(other, str):
+            return self.__class__(self.__root__ + [Plain(other)])
+        if isinstance(other, MessageComponent):
+            return self.__class__(self.__root__ + [other])
+        return NotImplemented
+
+    def __radd__(self, other: Union[MessageComponent, str]) -> 'MessageChain':
+        if isinstance(other, MessageComponent):
+            return self.__class__([other] + self.__root__)
+        if isinstance(other, str):
+            return self.__class__(
+                [cast(MessageComponent, Plain(other))] + self.__root__
+            )
+        return NotImplemented
+
+    def __mul__(self, other: int):
+        if isinstance(other, int):
+            return self.__class__(self.__root__ * other)
+        return NotImplemented
+
+    def __rmul__(self, other: int):
+        return self.__mul__(other)
+
+    def __iadd__(self, other: Iterable[Union[MessageComponent, str]]):
+        self.extend(other)
+
+    def __imul__(self, other: int):
+        if isinstance(other, int):
+            self.__root__ *= other
+        return NotImplemented
+
+    def index(
+        self,
+        x: Union[MessageComponent, Type[MessageComponent]],
+        i: int = 0,
+        j: int = -1
+    ) -> int:
+        """返回 x 在消息链中首次出现项的索引号（索引号在 i 或其后且在 j 之前）。
+
+        Args:
+            x (`Union[MessageComponent, Type[MessageComponent]]`):
+                要查找的消息元素或消息元素类型。
+            i: 从哪个位置开始查找。
+            j: 查找到哪个位置结束。
+
+        Returns:
+            int: 如果找到，则返回索引号。
+
+        Raises:
+            ValueError: 没有找到。
+            TypeError: 类型不匹配。
+        """
+        if isinstance(x, type):
+            l = len(self)
+            if i < 0:
+                i += l
+            if i < 0:
+                i = 0
+            if j < 0:
+                j += l
+            if j > l:
+                j = l
+            for index in range(i, j):
+                if type(self[index]) is x:
+                    return index
+            raise ValueError("消息链中不存在该类型的组件。")
+        if isinstance(x, MessageComponent):
+            return self.__root__.index(x, i, j)
+        raise TypeError(f"类型不匹配，当前类型：{type(x)}")
+
+    def count(self, x: Union[MessageComponent, Type[MessageComponent]]) -> int:
+        """返回消息链中 x 出现的次数。
+
+        Args:
+            x (`Union[MessageComponent, Type[MessageComponent]]`):
+                要查找的消息元素或消息元素类型。
+
+        Returns:
+            int: 次数。
+        """
+        if isinstance(x, type):
+            return sum(1 for i in self if type(i) is x)
+        if isinstance(x, MessageComponent):
+            return self.__root__.count(x)
+        raise TypeError(f"类型不匹配，当前类型：{type(x)}")
+
+    def extend(self, x: Iterable[Union[MessageComponent, str]]):
+        """将另一个消息链中的元素添加到消息链末尾。
+
+        Args:
+            x: 另一个消息链，也可为消息元素或字符串元素的序列。
+        """
+        self.__root__.extend(Plain(c) if isinstance(c, str) else c for c in x)
+
+    def append(self, x: Union[MessageComponent, str]):
+        """将一个消息元素或字符串元素添加到消息链末尾。
+
+        Args:
+            x: 消息元素或字符串元素。
+        """
+        self.__root__.append(Plain(x) if isinstance(x, str) else x)
+
+    def insert(self, i: int, x: Union[MessageComponent, str]):
+        """将一个消息元素或字符串添加到消息链中指定位置。
+
+        Args:
+            i: 插入位置。
+            x: 消息元素或字符串元素。
+        """
+        self.__root__.insert(i, Plain(x) if isinstance(x, str) else x)
+
+    def pop(self, i: int = -1) -> MessageComponent:
+        """从消息链中移除并返回指定位置的元素。
+
+        Args:
+            i: 移除位置。默认为末尾。
+
+        Returns:
+            MessageComponent: 移除的元素。
+        """
+        return self.__root__.pop(i)
+
+    def remove(self, x: Union[MessageComponent, Type[MessageComponent]]):
+        """从消息链中移除指定元素或指定类型的一个元素。
+
+        Args:
+            x: 指定的元素或元素类型。
+        """
+        if isinstance(x, type):
+            self.pop(self.index(x))
+        if isinstance(x, MessageComponent):
+            self.__root__.remove(x)
+
+    def exclude(
+        self,
+        x: Union[MessageComponent, Type[MessageComponent]],
+        count: int = -1
+    ) -> 'MessageChain':
+        """返回移除指定元素或指定类型的元素后剩余的消息链。
+
+        Args:
+            x: 指定的元素或元素类型。
+            count: 至多移除的数量。默认为全部移除。
+
+        Returns:
+            MessageChain: 剩余的消息链。
+        """
+        def _exclude():
+            nonlocal count
+            x_is_type = isinstance(x, type)
+            for c in self:
+                if count > 0 and ((x_is_type and type(c) is x) or c == x):
+                    count -= 1
+                    continue
+                yield c
+
+        return self.__class__(_exclude())
+
+    def reverse(self):
+        """将消息链原地翻转。"""
+        self.__root__.reverse()
+
+    @classmethod
+    def join(cls, *args: Iterable[Union[str, MessageComponent]]):
+        return cls(
+            Plain(c) if isinstance(c, str) else c
+            for c in itertools.chain(*args)
+        )
+
     @property
-    def source(self) -> 'Source':
+    def source(self) -> Optional['Source']:
         """获取消息链中的 `Source` 对象。"""
-        source = self[Source:1]
-        return cast(list, source)[0] if source else None
+        return self.get_first(Source)
 
     @property
     def message_id(self) -> int:
-        """获取消息链的 message_id。"""
+        """获取消息链的 message_id，若无法获取，返回 -1。"""
         source = self.source
         return source.id if source else -1
 
 
+TMessage = Union[MessageChain, Iterable[Union[MessageComponent, str]],
+                 MessageComponent, str]
+"""可以转化为 MessageChain 的类型。"""
+
+
 class Source(MessageComponent):
     """源。包含消息的基本信息。"""
     type: str = "Source"
@@ -367,7 +704,7 @@ class At(MessageComponent):
     target: int
     """群员 QQ 号。"""
     display: Optional[str] = None
-    """At时显示的文字，发送消息时无效，自动使用群名片"""
+    """At时显示的文字，发送消息时无效，自动使用群名片。"""
     def __eq__(self, other):
         return isinstance(other, At) and self.target == other.target
 
@@ -416,7 +753,7 @@ class Image(MessageComponent):
     """图片的 image_id，群图片与好友图片格式不同。不为空时将忽略 url 属性。"""
     url: Optional[HttpUrl] = None
     """图片的 URL，发送时可作网络图片的链接；接收时为腾讯图片服务器的链接，可用于图片下载。"""
-    path: Optional[Union[str, Path]] = None
+    path: Union[str, Path, None] = None
     """图片的路径，发送本地图片。"""
     base64: Optional[str] = None
     """图片的 Base64 编码。"""
@@ -429,7 +766,7 @@ class Image(MessageComponent):
         return f"[mirai:image:{self.image_id}]"
 
     @validator('path')
-    def validate_path(cls, path: Optional[Union[str, Path]]):
+    def validate_path(cls, path: Union[str, Path, None]):
         """修复 path 参数的行为，使之相对于 YiriMirai 的启动路径。"""
         if path:
             try:
@@ -464,22 +801,22 @@ class Image(MessageComponent):
 
     async def download(
         self,
-        filename: Optional[Union[str, Path]] = None,
-        directory: Optional[Union[str, Path]] = None,
+        filename: Union[str, Path, None] = None,
+        directory: Union[str, Path, None] = None,
         determine_type: bool = True
     ):
         """下载图片到本地。
 
-        `filename: Optional[Union[str, Path]] = None` 下载到本地的文件路径。与 `directory` 二选一。
-
-        `directory: Optional[Union[str, Path]] = None` 下载到本地的文件夹路径。与 `filename` 二选一。
-
-        `determine_type: bool = True` 是否自动根据图片类型确定拓展名。
+        Args:
+            filename: 下载到本地的文件路径。与 `directory` 二选一。
+            directory: 下载到本地的文件夹路径。与 `filename` 二选一。
+            determine_type: 是否自动根据图片类型确定拓展名，默认为 True。
         """
         if not self.url:
             logger.warning(f'图片 `{self.uuid}` 无 url 参数，下载失败。')
             return
 
+        import httpx
         async with httpx.AsyncClient() as client:
             response = await client.get(self.url)
             response.raise_for_status()
@@ -488,17 +825,20 @@ class Image(MessageComponent):
             if filename:
                 path = Path(filename)
                 if determine_type:
+                    import imghdr
                     path = path.with_suffix(
                         '.' + str(imghdr.what(None, content))
                     )
                 path.parent.mkdir(parents=True, exist_ok=True)
             elif directory:
+                import imghdr
                 path = Path(directory)
                 path.mkdir(parents=True, exist_ok=True)
                 path = path / f'{self.uuid}.{imghdr.what(None, content)}'
             else:
                 raise ValueError("请指定文件路径或文件夹路径！")
 
+            import aiofiles
             async with aiofiles.open(path, 'wb') as f:
                 await f.write(content)
 
@@ -507,31 +847,40 @@ class Image(MessageComponent):
     @classmethod
     async def from_local(
         cls,
-        filename: Optional[Union[str, Path]] = None,
+        filename: Union[str, Path, None] = None,
         content: Optional[bytes] = None,
-    ):
+    ) -> "Image":
         """从本地文件路径加载图片，以 base64 的形式传递。
 
-        `filename: Optional[Union[str, Path]] = None` 从本地文件路径加载图片，与 `content` 二选一。
+        Args:
+            filename: 从本地文件路径加载图片，与 `content` 二选一。
+            content: 从本地文件内容加载图片，与 `filename` 二选一。
 
-        `content: Optional[bytes] = None` 从本地文件内容加载图片，与 `filename` 二选一。
+        Returns:
+            Image: 图片对象。
         """
         if content:
             pass
         if filename:
             path = Path(filename)
+            import aiofiles
             async with aiofiles.open(path, 'rb') as f:
                 content = await f.read()
         else:
             raise ValueError("请指定图片路径或图片内容！")
+        import base64
         img = cls(base64=base64.b64encode(content).decode())
         return img
 
     @classmethod
-    def from_unsafe_path(cls, path: Union[str, Path]):
+    def from_unsafe_path(cls, path: Union[str, Path]) -> "Image":
         """从不安全的路径加载图片。
 
-        `path: Union[str, Path]` 从不安全的路径加载图片。
+        Args:
+            path: 从不安全的路径加载图片。
+
+        Returns:
+            Image: 图片对象。
         """
         return cls.construct(path=str(path))
 
@@ -559,6 +908,7 @@ class App(MessageComponent):
     content: str
     """内容。"""
     def as_json(self):
+        from json import loads as json_loads
         return json_loads(self.content)
 
     def __str__(self):
@@ -603,7 +953,8 @@ POKE_ID = {
 }
 
 
-class PokeNames(str, MessagePart, Enum):
+class PokeNames(str, Enum):
+    """戳一戳名称。"""
     ChuoYiChuo = "ChuoYiChuo"
     BiXin = "BiXin"
     DianZan = "DianZan"
@@ -693,19 +1044,24 @@ class Voice(MessageComponent):
         else:
             return path
 
-    async def download(self, filename=None, directory=None):
+    async def download(
+        self,
+        filename: Union[str, Path, None] = None,
+        directory: Union[str, Path, None] = None
+    ):
         """下载语音到本地。
 
         语音采用 silk v3 格式，silk 格式的编码解码请使用 [graiax-silkcoder](https://pypi.org/project/graiax-silkcoder/)。
 
-        `filename = None` 下载到本地的文件路径。与 `directory` 二选一。
-
-        `directory = None` 下载到本地的文件夹路径。与 `filename` 二选一。
+        Args:
+            filename: 下载到本地的文件路径。与 `directory` 二选一。
+            directory: 下载到本地的文件夹路径。与 `filename` 二选一。
         """
         if not self.url:
             logger.warning(f'语音 `{self.voice_id}` 无 url 参数，下载失败。')
             return
 
+        import httpx
         async with httpx.AsyncClient() as client:
             response = await client.get(self.url)
             response.raise_for_status()
@@ -721,29 +1077,32 @@ class Voice(MessageComponent):
             else:
                 raise ValueError("请指定文件路径或文件夹路径！")
 
+            import aiofiles
             async with aiofiles.open(path, 'wb') as f:
                 await f.write(content)
 
     @classmethod
     async def from_local(
         cls,
-        filename: Optional[Union[str, Path]] = None,
+        filename: Union[str, Path, None] = None,
         content: Optional[bytes] = None,
     ) -> "Voice":
         """从本地文件路径加载语音，以 base64 的形式传递。
 
-        `filename: Optional[Union[str, Path]] = None` 从本地文件路径加载图片，与 `content` 二选一。
-
-        `content: Optional[bytes] = None` 从本地文件内容加载图片，与 `filename` 二选一。
+        Args:
+            filename: 从本地文件路径加载语音，与 `content` 二选一。
+            content: 从本地文件内容加载语音，与 `filename` 二选一。
         """
         if content:
             pass
         if filename:
             path = Path(filename)
+            import aiofiles
             async with aiofiles.open(path, 'rb') as f:
                 content = await f.read()
         else:
             raise ValueError("请指定语音路径或语音内容！")
+        import base64
         img = cls(base64=base64.b64encode(content).decode())
         return img
 
@@ -803,13 +1162,21 @@ class ForwardMessageNode(MiraiBaseModel):
     def _validate_message_chain(cls, value: Union[MessageChain, list]):
         if isinstance(value, list):
             return MessageChain.parse_obj(value)
-        elif isinstance(value, MessageChain):
-            return value
+        return value
 
     @classmethod
     def create(
         cls, sender: Union[Friend, GroupMember], message: MessageChain
     ) -> 'ForwardMessageNode':
+        """从生成转发消息。
+
+        Args:
+            sender: 发送人。
+            message: 消息内容。
+
+        Returns:
+            ForwardMessageNode: 生成的一条消息。
+        """
         return ForwardMessageNode(
             sender_id=sender.id,
             sender_name=sender.get_name(),
@@ -881,4 +1248,5 @@ __all__ = [
     'Xml',
     'serialize',
     'deserialize',
+    'TMessage',
 ]
